The Wikipedia extension - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# The Wikipedia extension

The `betty.extension.Wikipedia` extension renders summaries of Wikipedia articles. If a entity such as a person or a place contains links to Wikipedia articles, templates can use this extension to fetch translated summaries of these articles, and render them on the entity’s page.

Enable this extension through Betty Desktop, or in your project’s configuration file as follows:

YAML

    extensions:
      betty.extension.Wikipedia: {}

JSON

    {
      "extensions": {
        "betty.extension.Wikipedia": {}
      }
    }

## Configuration

This extension is configurable through Betty Desktop or in the configuration file:

YAML

    extensions:
      betty.extension.Wikipedia:
        configuration:
          populate_images: false

JSON

    {
      "extensions": {
        "betty.extension.Wikipedia": {
          "configuration" : {
            "populate_images": false
          }
        }
      }
    }

### All configuration options

- `populate_images` (optional): A boolean indicating whether to download images from the Wikipedia links in the ancestry. Defaults to `true`.